@@ -2,7 +2,7 @@
 #[cfg(any(feature = "fmt", feature = "fmt_no_tty"))]
 use std::borrow::Cow;
 use std::fmt::{Debug, Display, Formatter, Write};
-use std::str::FromStr;
+use std::num::IntErrorKind;
 use std::sync::RwLock;
 use std::{fmt, str};
 
@@ -94,20 +94,23 @@ pub fn set_trim_decimal_zeros(trim: Option<bool>) {
     arrow::compute::decimal::set_trim_decimal_zeros(trim)
 }
 
-/// Parses an environment variable value.
-fn parse_env_var<T: FromStr>(name: &str) -> Option<T> {
-    std::env::var(name).ok().and_then(|v| v.parse().ok())
-}
 /// Parses an environment variable value as a limit or set a default.
 ///
 /// Negative values (e.g. -1) are parsed as 'no limit' or [`usize::MAX`].
 fn parse_env_var_limit(name: &str, default: usize) -> usize {
-    parse_env_var(name).map_or(
-        default,
-        |n: i64| {
-            if n < 0 { usize::MAX } else { n as usize }
+    let Ok(v) = std::env::var(name) else {
+        return default;
+    };
+
+    let n = match v.parse::<i64>() {
+        Ok(n) => n,
+        Err(e) => match e.kind() {
+            IntErrorKind::PosOverflow | IntErrorKind::NegOverflow => -1,
+            _ => return default,
         },
-    )
+    };
+
+    if n < 0 { usize::MAX } else { n as usize }
 }
 
 fn get_row_limit() -> usize {
