@@ -2,7 +2,7 @@ use polars_core::chunked_array::cast::CastOptions;
 use polars_core::prelude::arity::unary_elementwise_values;
 use polars_core::prelude::*;
 use polars_ops::prelude::lst_get;
-use polars_ops::series::convert_to_unsigned_index;
+use polars_ops::series::convert_and_bound_index;
 use polars_utils::index::ToIdx;
 
 use super::*;
@@ -24,11 +24,8 @@ impl PhysicalExpr for GatherExpr {
     fn evaluate(&self, df: &DataFrame, state: &ExecutionState) -> PolarsResult<Column> {
         let series = self.phys_expr.evaluate(df, state)?;
         let idx = self.idx.evaluate(df, state)?;
-        let idx = convert_to_unsigned_index(
-            idx.as_materialized_series(),
-            series.len(),
-            self.null_on_oob,
-        )?;
+        let idx =
+            convert_and_bound_index(idx.as_materialized_series(), series.len(), self.null_on_oob)?;
         series.take(&idx)
     }
 
