@@ -7,6 +7,7 @@ use recursive::recursive;
 use crate::dispatch::{function_expr_to_groups_udf, function_expr_to_udf};
 use crate::expressions as phys_expr;
 use crate::expressions::*;
+use crate::reduce::GroupedReduction;
 
 pub fn get_expr_depth_limit() -> PolarsResult<u16> {
     let depth = if let Ok(d) = std::env::var("POLARS_MAX_EXPR_DEPTH") {
@@ -378,53 +379,14 @@ fn create_physical_expr_inner(
                 .get(expression)
                 .to_field(&ToFieldContext::new(expr_arena, schema))?;
 
-            // Special case: Quantile, MinBy and MaxBy supports multiple inputs.
+            // Special case: Quantile supports multiple inputs.
             // TODO refactor to FunctionExpr.
-            match agg {
-                IRAggExpr::Quantile {
-                    quantile,
-                    method: interpol,
-                    ..
-                } => {
-                    let quantile = create_physical_expr_inner(quantile, expr_arena, schema, state)?;
-                    return Ok(Arc::new(AggQuantileExpr::new(input, quantile, interpol)));
-                },
-                IRAggExpr::MinBy { input, by } => {
-                    let arg_min_aexpr = AExpr::Function {
-                        input: vec![ExprIR::from_node(by, expr_arena)],
-                        function: IRFunctionExpr::ArgMin,
-                        options: FunctionOptions::aggregation(),
-                    };
-                    let arg_min = expr_arena.add(arg_min_aexpr);
-                    let gather_aexpr = AExpr::Gather {
-                        expr: input,
-                        idx: arg_min,
-                        returns_scalar: true,
-                        null_on_oob: false,
-                    };
-                    let gather = expr_arena.add(gather_aexpr);
-
-                    return create_physical_expr_inner(gather, expr_arena, schema, state);
-                },
-
-                IRAggExpr::MaxBy { input, by } => {
-                    let arg_min_aexpr = AExpr::Function {
-                        input: vec![ExprIR::from_node(by, expr_arena)],
-                        function: IRFunctionExpr::ArgMax,
-                        options: FunctionOptions::aggregation(),
-                    };
-                    let arg_min = expr_arena.add(arg_min_aexpr);
-                    let gather_aexpr = AExpr::Gather {
-                        expr: input,
-                        idx: arg_min,
-                        returns_scalar: true,
-                        null_on_oob: false,
-                    };
-                    let gather = expr_arena.add(gather_aexpr);
-
-                    return create_physical_expr_inner(gather, expr_arena, schema, state);
-                },
-                _ => {},
+            if let IRAggExpr::Quantile {
+                quantile, method, ..
+            } = agg
+            {
+                let quantile = create_physical_expr_inner(quantile, expr_arena, schema, state)?;
+                return Ok(Arc::new(AggQuantileExpr::new(input, quantile, method)));
             }
 
             let groupby = GroupByMethod::from(agg.clone());
@@ -440,6 +402,66 @@ fn create_physical_expr_inner(
                 output_field,
             )))
         },
+        Function {
+            input,
+            function: function @ (IRFunctionExpr::ArgMin | IRFunctionExpr::ArgMax),
+            options: _,
+        } => {
+            let phys_input =
+                create_physical_expr_inner(input[0].node(), expr_arena, schema, state)?;
+
+            let mut output_field = expr_arena
+                .get(expression)
+                .to_field(&ToFieldContext::new(expr_arena, schema))?;
+            output_field = Field::new(output_field.name().clone(), IDX_DTYPE.clone());
+
+            let groupby = match function {
+                IRFunctionExpr::ArgMin => GroupByMethod::ArgMin,
+                IRFunctionExpr::ArgMax => GroupByMethod::ArgMax,
+                _ => unreachable!(), // guaranteed by pattern
+            };
+
+            let agg_type = AggregationType {
+                groupby,
+                allow_threading: state.allow_threading,
+            };
+
+            Ok(Arc::new(AggregationExpr::new(
+                phys_input,
+                agg_type,
+                output_field,
+            )))
+        },
+        Function {
+            input: inputs,
+            function: function @ (IRFunctionExpr::MinBy | IRFunctionExpr::MaxBy),
+            options: _,
+        } => {
+            assert!(inputs.len() == 2);
+            let input = inputs[0].node();
+            let by = inputs[1].node();
+            let arg_fn = match function {
+                IRFunctionExpr::MinBy => IRFunctionExpr::ArgMin,
+                IRFunctionExpr::MaxBy => IRFunctionExpr::ArgMax,
+                _ => unreachable!(), // guaranteed by pattern
+            };
+
+            let arg_min_aexpr = AExpr::Function {
+                input: vec![ExprIR::from_node(by, expr_arena)],
+                function: arg_fn,
+                options: FunctionOptions::aggregation(),
+            };
+            let arg_min = expr_arena.add(arg_min_aexpr);
+            let gather_aexpr = AExpr::Gather {
+                expr: input,
+                idx: arg_min,
+                returns_scalar: true,
+                null_on_oob: false,
+            };
+            let gather = expr_arena.add(gather_aexpr);
+
+            return create_physical_expr_inner(gather, expr_arena, schema, state);
+        },
         Cast {
             expr,
             dtype,
@@ -478,6 +500,30 @@ fn create_physical_expr_inner(
                 is_scalar,
             )))
         },
+        AExpr::AnonymousAgg {
+            input,
+            fmt_str: _,
+            function,
+        } => {
+            let output_field = expr_arena
+                .get(expression)
+                .to_field(&ToFieldContext::new(expr_arena, schema))?;
+
+            let inputs = create_physical_expressions_from_irs(&input, expr_arena, schema, state)?;
+            let grouped_reduction = function
+                .clone()
+                .materialize()?
+                .as_any()
+                .downcast_ref::<Box<dyn GroupedReduction>>()
+                .unwrap()
+                .new_empty();
+
+            Ok(Arc::new(AnonymousAggregationExpr::new(
+                inputs,
+                grouped_reduction,
+                output_field,
+            )))
+        },
         AnonymousFunction {
             input,
             function,
@@ -582,9 +628,11 @@ fn create_physical_expr_inner(
             options,
         } => {
             let is_scalar = is_scalar_ae(expression, expr_arena);
+
             let output_field = expr_arena
                 .get(expression)
                 .to_field(&ToFieldContext::new(expr_arena, schema))?;
+
             let input = create_physical_expressions_from_irs(&input, expr_arena, schema, state)?;
             let is_fallible = expr_arena.get(expression).is_fallible_top_level(expr_arena);
 
@@ -601,6 +649,7 @@ fn create_physical_expr_inner(
                 is_fallible,
             )))
         },
+
         Slice {
             input,
             offset,
@@ -639,8 +688,5 @@ fn create_physical_expr_inner(
                 false,
             )))
         },
-        AnonymousStreamingAgg { .. } => {
-            polars_bail!(ComputeError: "anonymous agg not supported in in-memory engine")
-        },
     }
 }
