@@ -2149,7 +2149,7 @@ impl LazyGroupBy {
             .collect::<Vec<_>>();
 
         self.agg([all().as_expr().head(n)]).explode_impl(
-            all() - by_name(keys.iter().cloned(), false),
+            all() - by_name(keys.iter().cloned(), false, false),
             ExplodeOptions {
                 empty_as_null: true,
                 keep_nulls: true,
@@ -2167,7 +2167,7 @@ impl LazyGroupBy {
             .collect::<Vec<_>>();
 
         self.agg([all().as_expr().tail(n)]).explode_impl(
-            all() - by_name(keys.iter().cloned(), false),
+            all() - by_name(keys.iter().cloned(), false, false),
             ExplodeOptions {
                 empty_as_null: true,
                 keep_nulls: true,
