@@ -12,7 +12,7 @@ fn test_schema_update_after_projection_pd() -> PolarsResult<()> {
         .lazy()
         .with_column(col("a").implode())
         .explode(
-            by_name(["a"], true),
+            by_name(["a"], true, false),
             ExplodeOptions {
                 empty_as_null: true,
                 keep_nulls: true,
