@@ -3,8 +3,6 @@ mod format;
 pub mod inputs;
 mod schema;
 pub(crate) mod tree_format;
-#[cfg(feature = "ir_visualization")]
-pub mod visualization;
 
 use std::borrow::Cow;
 use std::fmt;
