@@ -54,9 +54,11 @@ impl<'py> IntoPyObject<'py> for &Wrap<AnyValue<'_>> {
     }
 }
 
-impl<'py> FromPyObject<'py> for Wrap<AnyValue<'static>> {
-    fn extract_bound(ob: &Bound<'py, PyAny>) -> PyResult<Self> {
-        py_object_to_any_value(ob, true, true).map(Wrap)
+impl<'a, 'py> FromPyObject<'a, 'py> for Wrap<AnyValue<'static>> {
+    type Error = PyErr;
+
+    fn extract(ob: Borrowed<'a, 'py, PyAny>) -> PyResult<Self> {
+        py_object_to_any_value(&ob.to_owned(), true, true).map(Wrap)
     }
 }
 
@@ -218,18 +220,9 @@ pub(crate) fn py_object_to_any_value(
     }
 
     fn get_str(ob: &Bound<'_, PyAny>, _strict: bool) -> PyResult<AnyValue<'static>> {
-        // Ideally we'd be returning an AnyValue::String(&str) instead, as was
-        // the case in previous versions of this function. However, if compiling
-        // with abi3 for versions older than Python 3.10, the APIs that purport
-        // to return &str actually just encode to UTF-8 as a newly allocated
-        // PyBytes object, and then return reference to that. So what we're
-        // doing here isn't any different fundamentally, and the APIs to for
-        // converting to &str are deprecated in PyO3 0.21.
-        //
-        // Once Python 3.10 is the minimum supported version, converting to &str
-        // will be cheaper, and we should do that. Python 3.9 security updates
-        // end-of-life is Oct 31, 2025.
-        Ok(AnyValue::StringOwned(ob.extract::<String>()?.into()))
+        Ok(AnyValue::StringOwned(PlSmallStr::from(
+            ob.extract::<&str>()?,
+        )))
     }
 
     fn get_bytes(ob: &Bound<'_, PyAny>, _strict: bool) -> PyResult<AnyValue<'static>> {
@@ -261,13 +254,13 @@ pub(crate) fn py_object_to_any_value(
             .ok()
             .and_then(|tz| (!tz.is_none()).then_some(tz))
         {
-            let tzinfo = PyTzInfo::timezone(py, tz.downcast_into::<PyString>()?)?;
+            let tzinfo = PyTzInfo::timezone(py, tz.cast_into::<PyString>()?)?;
             (
                 &ob.call_method(intern!(py, "astimezone"), (&tzinfo,), None)?,
                 tzinfo,
             )
         } else {
-            (ob, tzinfo.downcast_into()?)
+            (ob, tzinfo.cast_into()?)
         };
 
         let (timestamp, tz) = if tzinfo.hasattr(intern!(py, "key"))? {
@@ -377,7 +370,7 @@ pub(crate) fn py_object_to_any_value(
                 &DataType::Null,
             )))
         } else if ob.is_instance_of::<PyList>() | ob.is_instance_of::<PyTuple>() {
-            let list = ob.downcast::<PySequence>()?;
+            let list = ob.cast::<PySequence>()?;
 
             // Try to find first non-null.
             let length = list.len()?;
@@ -436,13 +429,13 @@ pub(crate) fn py_object_to_any_value(
     }
 
     fn get_mapping(ob: &Bound<'_, PyAny>, strict: bool) -> PyResult<AnyValue<'static>> {
-        let mapping = ob.downcast::<PyMapping>()?;
+        let mapping = ob.cast::<PyMapping>()?;
         let len = mapping.len()?;
         let mut keys = Vec::with_capacity(len);
         let mut vals = Vec::with_capacity(len);
 
         for item in mapping.items()?.try_iter()? {
-            let item = item?.downcast_into::<PyTuple>()?;
+            let item = item?.cast_into::<PyTuple>()?;
             let (key_py, val_py) = (item.get_item(0)?, item.get_item(1)?);
 
             let key: Cow<str> = key_py.extract()?;
@@ -455,7 +448,7 @@ pub(crate) fn py_object_to_any_value(
     }
 
     fn get_struct(ob: &Bound<'_, PyAny>, strict: bool) -> PyResult<AnyValue<'static>> {
-        let dict = ob.downcast::<PyDict>().unwrap();
+        let dict = ob.cast::<PyDict>().unwrap();
         let len = dict.len();
         let mut keys = Vec::with_capacity(len);
         let mut vals = Vec::with_capacity(len);
@@ -470,11 +463,11 @@ pub(crate) fn py_object_to_any_value(
     }
 
     fn get_namedtuple(ob: &Bound<'_, PyAny>, strict: bool) -> PyResult<AnyValue<'static>> {
-        let tuple = ob.downcast::<PyTuple>().unwrap();
+        let tuple = ob.cast::<PyTuple>().unwrap();
         let len = tuple.len();
         let fields = ob
             .getattr(intern!(ob.py(), "_fields"))?
-            .downcast_into::<PyTuple>()?;
+            .cast_into::<PyTuple>()?;
         let mut keys = Vec::with_capacity(len);
         let mut vals = Vec::with_capacity(len);
         for (k, v) in fields.into_iter().zip(tuple.into_iter()) {
