@@ -1,4 +1,3 @@
-use polars::lazy::dsl;
 use pyo3::prelude::*;
 
 use crate::PyExpr;
@@ -12,5 +11,5 @@ pub fn business_day_count(
 ) -> PyExpr {
     let start = start.inner;
     let end = end.inner;
-    dsl::business_day_count(start, end, week_mask, holidays).into()
+    polars_plan::dsl::functions::business_day_count(start, end, week_mask, holidays).into()
 }
