@@ -1,8 +1,8 @@
 use std::sync::{Arc, Mutex};
 
-use polars::prelude::sink2::FileProviderReturn;
+use polars::prelude::file_provider::FileProviderReturn;
 use polars::prelude::sync_on_close::SyncOnCloseType;
-use polars::prelude::{PartitionTargetCallbackResult, PlRefPath, SpecialEq};
+use polars::prelude::{PlRefPath, SpecialEq};
 use polars_error::polars_err;
 use pyo3::exceptions::PyValueError;
 use pyo3::prelude::*;
@@ -34,39 +34,6 @@ impl<'a, 'py> FromPyObject<'a, 'py> for Wrap<polars_plan::dsl::SinkTarget> {
     }
 }
 
-impl<'a, 'py> FromPyObject<'a, 'py> for Wrap<PartitionTargetCallbackResult> {
-    type Error = PyErr;
-
-    fn extract(ob: Borrowed<'a, 'py, PyAny>) -> PyResult<Self> {
-        if let Ok(v) = ob.extract::<PyBackedStr>() {
-            Ok(Wrap(polars::prelude::PartitionTargetCallbackResult::Str(
-                v.to_string(),
-            )))
-        } else if let Ok(v) = ob.extract::<std::path::PathBuf>() {
-            Ok(Wrap(polars::prelude::PartitionTargetCallbackResult::Str(
-                v.to_str()
-                    .ok_or_else(|| to_py_err(polars_err!(non_utf8_path)))?
-                    .to_string(),
-            )))
-        } else {
-            let writer = Python::attach(|py| {
-                let py_f = ob.to_owned();
-                PyResult::Ok(
-                    crate::file::try_get_pyfile(py, py_f, true)?
-                        .0
-                        .into_writeable(),
-                )
-            })?;
-
-            Ok(Wrap(
-                polars_plan::prelude::PartitionTargetCallbackResult::Dyn(SpecialEq::new(Arc::new(
-                    Mutex::new(Some(writer)),
-                ))),
-            ))
-        }
-    }
-}
-
 impl<'a, 'py> FromPyObject<'a, 'py> for Wrap<FileProviderReturn> {
     type Error = PyErr;
 
