@@ -85,17 +85,31 @@ impl PySeries {
     fn quantile<'py>(
         &self,
         py: Python<'py>,
-        quantile: f64,
+        quantile: Bound<'py, PyAny>,
         interpolation: Wrap<QuantileMethod>,
     ) -> PyResult<Bound<'py, PyAny>> {
-        scalar_to_py(
-            py.enter_polars(|| {
-                self.series
-                    .read()
-                    .quantile_reduce(quantile, interpolation.0)
-            }),
-            py,
-        )
+        // Accept either a single float or a list of floats
+        if let Ok(q_float) = quantile.extract::<f64>() {
+            // Single quantile: use quantile_reduce
+            scalar_to_py(
+                py.enter_polars(|| self.series.read().quantile_reduce(q_float, interpolation.0)),
+                py,
+            )
+        } else if let Ok(q_list) = quantile.extract::<Vec<f64>>() {
+            // Multiple quantiles: use quantiles_reduce
+            scalar_to_py(
+                py.enter_polars(|| {
+                    self.series
+                        .read()
+                        .quantiles_reduce(&q_list, interpolation.0)
+                }),
+                py,
+            )
+        } else {
+            Err(PyErr::new::<pyo3::exceptions::PyTypeError, _>(
+                "quantile must be a float or a list of floats",
+            ))
+        }
     }
 
     fn std<'py>(&self, py: Python<'py>, ddof: u8) -> PyResult<Bound<'py, PyAny>> {
