@@ -1,4 +1,4 @@
-use core::fmt::{Debug, Formatter};
+use core::fmt::Debug;
 use core::hash::{Hash, Hasher};
 
 use indexmap::map::MutableKeys;
@@ -6,21 +6,60 @@ use polars_error::{PolarsError, PolarsResult, polars_bail, polars_ensure, polars
 use polars_utils::aliases::{InitHashMaps, PlIndexMap};
 use polars_utils::pl_str::PlSmallStr;
 
-#[derive(Clone, Default)]
+#[derive(Debug, Clone, Default)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 #[cfg_attr(feature = "dsl-schema", derive(schemars::JsonSchema))]
-pub struct Schema<D> {
-    fields: PlIndexMap<PlSmallStr, D>,
+pub struct Schema<Field, Metadata> {
+    fields: PlIndexMap<PlSmallStr, Field>,
+    metadata: Metadata,
 }
 
-impl<D: Eq> Eq for Schema<D> {}
+impl<Field: Eq, Metadata: Eq> Eq for Schema<Field, Metadata> {}
 
-impl<D> Schema<D> {
+impl<Field, Metadata: Default> Schema<Field, Metadata> {
     pub fn with_capacity(capacity: usize) -> Self {
         let fields = PlIndexMap::with_capacity(capacity);
-        Self { fields }
+        Self {
+            fields,
+            metadata: Metadata::default(),
+        }
     }
 
+    pub fn from_iter_check_duplicates<I, F>(iter: I) -> PolarsResult<Self>
+    where
+        I: IntoIterator<Item = F>,
+        F: Into<(PlSmallStr, Field)>,
+    {
+        Self::try_from_iter_check_duplicates(
+            iter.into_iter().map(PolarsResult::Ok),
+            |name: &str| polars_err!(Duplicate: "duplicate name when building schema '{}'", &name),
+        )
+    }
+
+    pub fn try_from_iter_check_duplicates<I, F, E>(iter: I, err_func: E) -> PolarsResult<Self>
+    where
+        I: IntoIterator<Item = PolarsResult<F>>,
+        F: Into<(PlSmallStr, Field)>,
+        E: Fn(&str) -> PolarsError,
+    {
+        let iter = iter.into_iter();
+        let mut slf = Self::with_capacity(iter.size_hint().1.unwrap_or(0));
+
+        for v in iter {
+            let (name, d) = v?.into();
+
+            if slf.contains(&name) {
+                return Err(err_func(&name));
+            }
+
+            slf.fields.insert(name, d);
+        }
+
+        Ok(slf)
+    }
+}
+
+impl<Field, Metadata> Schema<Field, Metadata> {
     /// Reserve `additional` memory spaces in the schema.
     pub fn reserve(&mut self, additional: usize) {
         self.fields.reserve(additional);
@@ -37,6 +76,14 @@ impl<D> Schema<D> {
         self.fields.is_empty()
     }
 
+    pub fn metadata(&self) -> &Metadata {
+        &self.metadata
+    }
+
+    pub fn metadata_mut(&mut self) -> &mut Metadata {
+        &mut self.metadata
+    }
+
     /// Rename field `old` to `new`, and return the (owned) old name.
     ///
     /// If `old` is not present in the schema, the schema is not modified and `None` is returned. Otherwise the schema
@@ -53,7 +100,7 @@ impl<D> Schema<D> {
         Some(old_name)
     }
 
-    pub fn insert(&mut self, key: PlSmallStr, value: D) -> Option<D> {
+    pub fn insert(&mut self, key: PlSmallStr, value: Field) -> Option<Field> {
         self.fields.insert(key, value)
     }
 
@@ -75,8 +122,8 @@ impl<D> Schema<D> {
         &mut self,
         mut index: usize,
         name: PlSmallStr,
-        dtype: D,
-    ) -> PolarsResult<Option<D>> {
+        dtype: Field,
+    ) -> PolarsResult<Option<Field>> {
         polars_ensure!(
             index <= self.len(),
             OutOfBounds:
@@ -97,23 +144,23 @@ impl<D> Schema<D> {
     }
 
     /// Get a reference to the dtype of the field named `name`, or `None` if the field doesn't exist.
-    pub fn get(&self, name: &str) -> Option<&D> {
+    pub fn get(&self, name: &str) -> Option<&Field> {
         self.fields.get(name)
     }
 
     /// Get a mutable reference to the dtype of the field named `name`, or `None` if the field doesn't exist.
-    pub fn get_mut(&mut self, name: &str) -> Option<&mut D> {
+    pub fn get_mut(&mut self, name: &str) -> Option<&mut Field> {
         self.fields.get_mut(name)
     }
 
     /// Get a reference to the dtype of the field named `name`, or `Err(PolarsErr)` if the field doesn't exist.
-    pub fn try_get(&self, name: &str) -> PolarsResult<&D> {
+    pub fn try_get(&self, name: &str) -> PolarsResult<&Field> {
         self.get(name)
             .ok_or_else(|| polars_err!(SchemaFieldNotFound: "{}", name))
     }
 
     /// Get a mutable reference to the dtype of the field named `name`, or `Err(PolarsErr)` if the field doesn't exist.
-    pub fn try_get_mut(&mut self, name: &str) -> PolarsResult<&mut D> {
+    pub fn try_get_mut(&mut self, name: &str) -> PolarsResult<&mut Field> {
         self.fields
             .get_mut(name)
             .ok_or_else(|| polars_err!(SchemaFieldNotFound: "{}", name))
@@ -122,14 +169,14 @@ impl<D> Schema<D> {
     /// Return all data about the field named `name`: its index in the schema, its name, and its dtype.
     ///
     /// Returns `Some((index, &name, &dtype))` if the field exists, `None` if it doesn't.
-    pub fn get_full(&self, name: &str) -> Option<(usize, &PlSmallStr, &D)> {
+    pub fn get_full(&self, name: &str) -> Option<(usize, &PlSmallStr, &Field)> {
         self.fields.get_full(name)
     }
 
     /// Return all data about the field named `name`: its index in the schema, its name, and its dtype.
     ///
     /// Returns `Ok((index, &name, &dtype))` if the field exists, `Err(PolarsErr)` if it doesn't.
-    pub fn try_get_full(&self, name: &str) -> PolarsResult<(usize, &PlSmallStr, &D)> {
+    pub fn try_get_full(&self, name: &str) -> PolarsResult<(usize, &PlSmallStr, &Field)> {
         self.fields
             .get_full(name)
             .ok_or_else(|| polars_err!(SchemaFieldNotFound: "{}", name))
@@ -139,11 +186,11 @@ impl<D> Schema<D> {
     ///
     /// If `index` is inbounds, returns `Some((&name, &dtype))`, else `None`. See
     /// [`get_at_index_mut`][Self::get_at_index_mut] for a mutable version.
-    pub fn get_at_index(&self, index: usize) -> Option<(&PlSmallStr, &D)> {
+    pub fn get_at_index(&self, index: usize) -> Option<(&PlSmallStr, &Field)> {
         self.fields.get_index(index)
     }
 
-    pub fn try_get_at_index(&self, index: usize) -> PolarsResult<(&PlSmallStr, &D)> {
+    pub fn try_get_at_index(&self, index: usize) -> PolarsResult<(&PlSmallStr, &Field)> {
         self.fields.get_index(index).ok_or_else(|| polars_err!(ComputeError: "index {index} out of bounds with 'schema' of len: {}", self.len()))
     }
 
@@ -151,7 +198,7 @@ impl<D> Schema<D> {
     ///
     /// If `index` is inbounds, returns `Some((&mut name, &mut dtype))`, else `None`. See
     /// [`get_at_index`][Self::get_at_index] for an immutable version.
-    pub fn get_at_index_mut(&mut self, index: usize) -> Option<(&mut PlSmallStr, &mut D)> {
+    pub fn get_at_index_mut(&mut self, index: usize) -> Option<(&mut PlSmallStr, &mut Field)> {
         self.fields.get_index_mut2(index)
     }
 
@@ -162,7 +209,7 @@ impl<D> Schema<D> {
     /// This method does a `swap_remove`, which is O(1) but **changes the order of the schema**: the field named `name`
     /// is replaced by the last field, which takes its position. For a slower, but order-preserving, method, use
     /// [`shift_remove`][Self::shift_remove].
-    pub fn remove(&mut self, name: &str) -> Option<D> {
+    pub fn remove(&mut self, name: &str) -> Option<Field> {
         self.fields.swap_remove(name)
     }
 
@@ -172,7 +219,7 @@ impl<D> Schema<D> {
     ///
     /// This method does a `shift_remove`, which preserves the order of the fields in the schema but **is O(n)**. For a
     /// faster, but not order-preserving, method, use [`remove`][Self::remove].
-    pub fn shift_remove(&mut self, name: &str) -> Option<D> {
+    pub fn shift_remove(&mut self, name: &str) -> Option<Field> {
         self.fields.shift_remove(name)
     }
 
@@ -182,7 +229,7 @@ impl<D> Schema<D> {
     ///
     /// This method does a `shift_remove`, which preserves the order of the fields in the schema but **is O(n)**. For a
     /// faster, but not order-preserving, method, use [`remove`][Self::remove].
-    pub fn shift_remove_index(&mut self, index: usize) -> Option<(PlSmallStr, D)> {
+    pub fn shift_remove_index(&mut self, index: usize) -> Option<(PlSmallStr, Field)> {
         self.fields.shift_remove_index(index)
     }
 
@@ -198,7 +245,7 @@ impl<D> Schema<D> {
     ///
     /// This method only ever modifies an existing field and never adds a new field to the schema. To add a new field,
     /// use [`with_column`][Self::with_column] or [`insert_at_index`][Self::insert_at_index].
-    pub fn set_dtype(&mut self, name: &str, dtype: D) -> Option<D> {
+    pub fn set_dtype(&mut self, name: &str, dtype: Field) -> Option<Field> {
         let old_dtype = self.fields.get_mut(name)?;
         Some(std::mem::replace(old_dtype, dtype))
     }
@@ -210,7 +257,7 @@ impl<D> Schema<D> {
     ///
     /// This method only ever modifies an existing index and never adds a new field to the schema. To add a new field,
     /// use [`with_column`][Self::with_column] or [`insert_at_index`][Self::insert_at_index].
-    pub fn set_dtype_at_index(&mut self, index: usize, dtype: D) -> Option<D> {
+    pub fn set_dtype_at_index(&mut self, index: usize, dtype: Field) -> Option<Field> {
         let (_, old_dtype) = self.fields.get_index_mut(index)?;
         Some(std::mem::replace(old_dtype, dtype))
     }
@@ -221,12 +268,12 @@ impl<D> Schema<D> {
     /// returns the old one. Otherwise, the column is inserted at the end.
     ///
     /// To enforce the index of the resulting field, use [`insert_at_index`][Self::insert_at_index].
-    pub fn with_column(&mut self, name: PlSmallStr, dtype: D) -> Option<D> {
+    pub fn with_column(&mut self, name: PlSmallStr, dtype: Field) -> Option<Field> {
         self.fields.insert(name, dtype)
     }
 
     /// Raises DuplicateError if this column already exists in the schema.
-    pub fn try_insert(&mut self, name: PlSmallStr, value: D) -> PolarsResult<()> {
+    pub fn try_insert(&mut self, name: PlSmallStr, value: Field) -> PolarsResult<()> {
         if self.fields.contains_key(&name) {
             polars_bail!(Duplicate: "column '{}' is duplicate", name)
         }
@@ -241,7 +288,7 @@ impl<D> Schema<D> {
     /// Raises DuplicateError if a column already exists in the schema.
     pub fn hstack_mut(
         &mut self,
-        columns: impl IntoIterator<Item = impl Into<(PlSmallStr, D)>>,
+        columns: impl IntoIterator<Item = impl Into<(PlSmallStr, Field)>>,
     ) -> PolarsResult<()> {
         for v in columns {
             let (k, v) = v.into();
@@ -256,12 +303,20 @@ impl<D> Schema<D> {
     /// Raises DuplicateError if a column already exists in the schema.
     pub fn hstack(
         mut self,
-        columns: impl IntoIterator<Item = impl Into<(PlSmallStr, D)>>,
+        columns: impl IntoIterator<Item = impl Into<(PlSmallStr, Field)>>,
     ) -> PolarsResult<Self> {
         self.hstack_mut(columns)?;
         Ok(self)
     }
 
+    pub fn sort_by_key<T, F>(&mut self, sort_key: F)
+    where
+        T: Ord,
+        F: FnMut(&PlSmallStr, &Field) -> T,
+    {
+        self.fields.sort_by_key(sort_key);
+    }
+
     /// Merge `other` into `self`.
     ///
     /// Merging logic:
@@ -276,11 +331,11 @@ impl<D> Schema<D> {
     /// Iterates over the `(&name, &dtype)` pairs in this schema.
     ///
     /// For an owned version, use [`iter_fields`][Self::iter_fields], which clones the data to iterate owned `Field`s
-    pub fn iter(&self) -> impl ExactSizeIterator<Item = (&PlSmallStr, &D)> + '_ {
+    pub fn iter(&self) -> impl ExactSizeIterator<Item = (&PlSmallStr, &Field)> + '_ {
         self.fields.iter()
     }
 
-    pub fn iter_mut(&mut self) -> impl ExactSizeIterator<Item = (&PlSmallStr, &mut D)> + '_ {
+    pub fn iter_mut(&mut self) -> impl ExactSizeIterator<Item = (&PlSmallStr, &mut Field)> + '_ {
         self.fields.iter_mut()
     }
 
@@ -294,16 +349,16 @@ impl<D> Schema<D> {
     }
 
     /// Iterates over references to the dtypes in this schema.
-    pub fn iter_values(&self) -> impl '_ + ExactSizeIterator<Item = &D> {
+    pub fn iter_values(&self) -> impl '_ + ExactSizeIterator<Item = &Field> {
         self.fields.iter().map(|(_name, dtype)| dtype)
     }
 
-    pub fn into_iter_values(self) -> impl ExactSizeIterator<Item = D> {
+    pub fn into_iter_values(self) -> impl ExactSizeIterator<Item = Field> {
         self.fields.into_values()
     }
 
     /// Iterates over mut references to the dtypes in this schema.
-    pub fn iter_values_mut(&mut self) -> impl '_ + ExactSizeIterator<Item = &mut D> {
+    pub fn iter_values_mut(&mut self) -> impl '_ + ExactSizeIterator<Item = &mut Field> {
         self.fields.iter_mut().map(|(_name, dtype)| dtype)
     }
 
@@ -327,8 +382,8 @@ impl<D> Schema<D> {
     pub fn field_compare<'a, 'b>(
         &'a self,
         other: &'b Self,
-        self_extra: &mut Vec<(usize, (&'a PlSmallStr, &'a D))>,
-        other_extra: &mut Vec<(usize, (&'b PlSmallStr, &'b D))>,
+        self_extra: &mut Vec<(usize, (&'a PlSmallStr, &'a Field))>,
+        other_extra: &mut Vec<(usize, (&'b PlSmallStr, &'b Field))>,
     ) {
         self_extra.extend(
             self.iter()
@@ -344,9 +399,10 @@ impl<D> Schema<D> {
     }
 }
 
-impl<D> Schema<D>
+impl<Field, Metadata> Schema<Field, Metadata>
 where
-    D: Clone + Default,
+    Field: Clone + Default,
+    Metadata: Clone,
 {
     /// Create a new schema from this one, inserting a field with `name` and `dtype` at the given `index`.
     ///
@@ -364,7 +420,7 @@ where
         &self,
         index: usize,
         name: PlSmallStr,
-        field: D,
+        field: Field,
     ) -> PolarsResult<Self> {
         polars_ensure!(
             index <= self.len(),
@@ -374,7 +430,10 @@ where
                     self.len()
         );
 
-        let mut new = Self::default();
+        let mut new = Self {
+            fields: Default::default(),
+            metadata: self.metadata().clone(),
+        };
         let mut iter = self.fields.iter().filter_map(|(fld_name, dtype)| {
             (fld_name != &name).then_some((fld_name.clone(), dtype.clone()))
         });
@@ -405,7 +464,7 @@ where
         I: IntoIterator,
         I::Item: AsRef<str>,
     {
-        let schema = columns
+        let fields = columns
             .into_iter()
             .map(|c| {
                 let name = c.as_ref();
@@ -416,7 +475,10 @@ where
                 PolarsResult::Ok((name.clone(), dtype.clone()))
             })
             .collect::<PolarsResult<PlIndexMap<PlSmallStr, _>>>()?;
-        Ok(Self::from(schema))
+        Ok(Self {
+            fields,
+            metadata: self.metadata().clone(),
+        })
     }
 
     pub fn try_project_indices(&self, indices: &[usize]) -> PolarsResult<Self> {
@@ -435,12 +497,16 @@ where
             })
             .collect::<PolarsResult<PlIndexMap<_, _>>>()?;
 
-        Ok(Self { fields })
+        Ok(Self {
+            fields,
+            metadata: self.metadata().clone(),
+        })
     }
 
     /// Returns a new [`Schema`] with a subset of all fields whose `predicate`
     /// evaluates to true.
-    pub fn filter<F: Fn(usize, &D) -> bool>(self, predicate: F) -> Self {
+    pub fn filter<F: Fn(usize, &Field) -> bool>(self, predicate: F) -> Self {
+        let metadata = self.metadata().clone();
         let fields = self
             .fields
             .into_iter()
@@ -454,102 +520,98 @@ where
             })
             .collect();
 
-        Self { fields }
-    }
-
-    pub fn from_iter_check_duplicates<I, F>(iter: I) -> PolarsResult<Self>
-    where
-        I: IntoIterator<Item = F>,
-        F: Into<(PlSmallStr, D)>,
-    {
-        Self::try_from_iter_check_duplicates(
-            iter.into_iter().map(PolarsResult::Ok),
-            |name: &str| polars_err!(Duplicate: "duplicate name when building schema '{}'", &name),
-        )
-    }
-
-    pub fn try_from_iter_check_duplicates<I, F, E>(iter: I, err_func: E) -> PolarsResult<Self>
-    where
-        I: IntoIterator<Item = PolarsResult<F>>,
-        F: Into<(PlSmallStr, D)>,
-        E: Fn(&str) -> PolarsError,
-    {
-        let iter = iter.into_iter();
-        let mut slf = Self::with_capacity(iter.size_hint().1.unwrap_or(0));
-
-        for v in iter {
-            let (name, d) = v?.into();
-
-            if slf.contains(&name) {
-                return Err(err_func(&name));
-            }
-
-            slf.fields.insert(name, d);
-        }
-
-        Ok(slf)
+        Self { fields, metadata }
     }
 }
 
-impl<D: Debug> Debug for Schema<D> {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        writeln!(f, "Schema:")?;
-        for (name, field) in self.fields.iter() {
-            writeln!(f, "name: {name}, field: {field:?}")?;
-        }
-        Ok(())
-    }
-}
-
-impl<D: Hash> Hash for Schema<D> {
+impl<Field: Hash, Metadata: Hash> Hash for Schema<Field, Metadata> {
     fn hash<H: Hasher>(&self, state: &mut H) {
-        self.fields.iter().for_each(|v| v.hash(state))
+        Hash::hash(&SchemaHashEqWrap::from(self), state)
     }
 }
 
 // Schemas will only compare equal if they have the same fields in the same order. We can't use `self.inner ==
 // other.inner` because [`IndexMap`] ignores order when checking equality, but we don't want to ignore it.
-impl<D: PartialEq> PartialEq for Schema<D> {
+impl<Field: PartialEq, Metadata: PartialEq> PartialEq for Schema<Field, Metadata> {
     fn eq(&self, other: &Self) -> bool {
-        self.fields.len() == other.fields.len()
-            && self
-                .fields
-                .iter()
-                .zip(other.fields.iter())
-                .all(|(a, b)| a == b)
+        PartialEq::eq(
+            &SchemaHashEqWrap::from(self),
+            &SchemaHashEqWrap::from(other),
+        )
     }
 }
 
-impl<D> From<PlIndexMap<PlSmallStr, D>> for Schema<D> {
-    fn from(fields: PlIndexMap<PlSmallStr, D>) -> Self {
-        Self { fields }
+/// Specialization
+/// * `IndexMap` eq impl does not consider key ordering, but we want key ordering.
+/// * `IndexMap` does not impl Hash.
+#[derive(Hash, PartialEq)]
+struct SchemaHashEqWrap<'a, Field, Metadata> {
+    fields: &'a indexmap::map::Slice<PlSmallStr, Field>,
+    metadata: &'a Metadata,
+}
+
+impl<'a, Field, Metadata> From<&'a Schema<Field, Metadata>>
+    for SchemaHashEqWrap<'a, Field, Metadata>
+{
+    fn from(value: &'a Schema<Field, Metadata>) -> Self {
+        let Schema { fields, metadata } = value;
+
+        Self {
+            fields: fields.as_slice(),
+            metadata,
+        }
     }
 }
 
-impl<F, D> FromIterator<F> for Schema<D>
+impl<Field, Metadata: Default> From<PlIndexMap<PlSmallStr, Field>> for Schema<Field, Metadata> {
+    fn from(fields: PlIndexMap<PlSmallStr, Field>) -> Self {
+        Self {
+            fields,
+            metadata: Metadata::default(),
+        }
+    }
+}
+
+impl<F, Field, Metadata: Default> FromIterator<F> for Schema<Field, Metadata>
 where
-    F: Into<(PlSmallStr, D)>,
+    F: Into<(PlSmallStr, Field)>,
 {
     fn from_iter<I: IntoIterator<Item = F>>(iter: I) -> Self {
         let fields = PlIndexMap::from_iter(iter.into_iter().map(|x| x.into()));
-        Self { fields }
+        Self {
+            fields,
+            metadata: Metadata::default(),
+        }
     }
 }
 
-impl<F, D> Extend<F> for Schema<D>
+impl<F, Field, Metadata> Extend<F> for Schema<Field, Metadata>
 where
-    F: Into<(PlSmallStr, D)>,
+    F: Into<(PlSmallStr, Field)>,
 {
     fn extend<T: IntoIterator<Item = F>>(&mut self, iter: T) {
         self.fields.extend(iter.into_iter().map(|x| x.into()))
     }
 }
 
-impl<D> IntoIterator for Schema<D> {
-    type IntoIter = <PlIndexMap<PlSmallStr, D> as IntoIterator>::IntoIter;
-    type Item = (PlSmallStr, D);
+impl<Field, Metadata> IntoIterator for Schema<Field, Metadata> {
+    type IntoIter = <PlIndexMap<PlSmallStr, Field> as IntoIterator>::IntoIter;
+    type Item = (PlSmallStr, Field);
 
     fn into_iter(self) -> Self::IntoIter {
         self.fields.into_iter()
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::Schema;
+
+    #[test]
+    fn test_schema_eq_checks_key_order() {
+        let lhs: Schema<(), ()> = Schema::from_iter([("a".into(), ()), ("b".into(), ())]);
+        let rhs: Schema<(), ()> = Schema::from_iter([("b".into(), ()), ("a".into(), ())]);
+
+        assert_ne!(lhs, rhs);
+    }
+}
