@@ -106,12 +106,18 @@ impl Graph {
                 );
             }
             let start = (metrics.is_some() || verbose).then(Instant::now);
+            if let Some(lock) = metrics {
+                lock.lock().start_state_update(node_key);
+            }
+
             node.compute
                 .update_state(&mut recv_state, &mut send_state, state)?;
             let elapsed = start.map(|s| s.elapsed());
             if let Some(lock) = metrics {
-                let mut m = lock.lock();
-                m.add_state_update(node_key, elapsed.unwrap());
+                let is_done = recv_state.iter().all(|s| *s == PortState::Done)
+                    && send_state.iter().all(|s| *s == PortState::Done);
+                lock.lock()
+                    .stop_state_update(node_key, elapsed.unwrap(), is_done);
             }
             if verbose {
                 eprintln!(
