@@ -51,8 +51,7 @@ impl FileReaderBuilder for IpcReaderBuilder {
         let prefetch_limit = std::env::var("POLARS_RECORD_BATCH_PREFETCH_SIZE")
             .map(|x| {
                 x.parse::<NonZeroUsize>()
-                    .ok()
-                    .unwrap_or_else(|| {
+                    .unwrap_or_else(|_| {
                         panic!("invalid value for POLARS_RECORD_BATCH_PREFETCH_SIZE: {x}")
                     })
                     .get()
