@@ -122,115 +122,104 @@ fn upsample_impl(
     stable: bool,
 ) -> PolarsResult<DataFrame> {
     let s = source.column(index_column)?;
-    let time_type = s.dtype();
-    match time_type {
-        #[cfg(feature = "dtype-date")]
-        DataType::Date => {
-            let mut df = source.clone();
-            df.apply(index_column, |s| {
-                s.cast(&DataType::Datetime(TimeUnit::Microseconds, None))
-                    .unwrap()
-            })
-            .unwrap();
-            let mut out = upsample_impl(&df, by, index_column, every, stable)?;
-            out.apply(index_column, |s| s.cast(time_type).unwrap())
-                .unwrap();
-            Ok(out)
-        },
-        DataType::UInt32 | DataType::UInt64 | DataType::Int32 => {
-            let mut df = source.clone();
+    let original_type = s.dtype();
 
-            df.apply(index_column, |s| {
-                s.cast(&DataType::Int64)
-                    .unwrap()
-                    .cast(&DataType::Datetime(TimeUnit::Nanoseconds, None))
-                    .unwrap()
-            })
-            .unwrap();
-            let mut out = upsample_impl(&df, by, index_column, every, stable)?;
-            out.apply(index_column, |s| s.cast(time_type).unwrap())
-                .unwrap();
-            Ok(out)
-        },
-        DataType::Int64 => {
-            let mut df = source.clone();
-            df.apply(index_column, |s| {
-                s.cast(&DataType::Datetime(TimeUnit::Nanoseconds, None))
-                    .unwrap()
-            })
-            .unwrap();
-            let mut out = upsample_impl(&df, by, index_column, every, stable)?;
-            out.apply(index_column, |s| s.cast(time_type).unwrap())
-                .unwrap();
-            Ok(out)
-        },
-        _ => {
-            if by.is_empty() {
-                let index_column = source.column(index_column)?;
-                upsample_single_impl(source, index_column.as_materialized_series(), every)
-            } else {
-                let source_schema = source.schema();
+    let needs_cast = matches!(
+        original_type,
+        DataType::Date | DataType::UInt32 | DataType::UInt64 | DataType::Int32 | DataType::Int64
+    );
 
-                let group_keys_df = source.select(by)?;
-                let group_keys_schema = group_keys_df.schema();
+    let mut df = source.clone();
 
-                let groups = if stable {
-                    group_keys_df.group_by_stable(group_keys_schema.iter_names_cloned())
-                } else {
-                    group_keys_df.group_by(group_keys_schema.iter_names_cloned())
-                }?
-                .into_groups();
-
-                let non_group_keys_df = unsafe {
-                    source.select_unchecked(
-                        source_schema
-                            .iter_names()
-                            .filter(|name| !group_keys_schema.contains(name.as_str())),
-                    )?
-                };
-
-                let upsample_index_col_idx: Option<usize> =
-                    non_group_keys_df.schema().index_of(index_column);
-
-                // don't parallelize this, this may SO on large data.
-                let dfs: Vec<DataFrame> = groups
-                    .iter()
-                    .map(|g| {
-                        let first_idx = g.first();
-
-                        let mut non_group_keys_df =
-                            unsafe { non_group_keys_df.gather_group_unchecked(&g) };
-
-                        if let Some(i) = upsample_index_col_idx {
-                            non_group_keys_df = upsample_single_impl(
-                                &non_group_keys_df,
-                                non_group_keys_df.columns()[i].as_materialized_series(),
-                                every,
-                            )?
-                        }
-
-                        let mut out = non_group_keys_df;
-
-                        let group_keys_df =
-                            group_keys_df.new_from_index(first_idx as usize, out.height());
-
-                        let out_cols = unsafe { out.columns_mut() };
-
-                        out_cols.reserve(group_keys_df.width());
-                        out_cols.extend(group_keys_df.into_columns());
-
-                        Ok(out)
-                    })
-                    .collect::<PolarsResult<_>>()?;
-
-                Ok(unsafe {
-                    accumulate_dataframes_vertical_unchecked(dfs)
-                        .select_unchecked(source_schema.iter_names())?
-                        .with_schema(source_schema.clone())
-                })
-            }
-        },
+    if needs_cast {
+        df.try_apply(index_column, |s| match s.dtype() {
+            #[cfg(feature = "dtype-date")]
+            DataType::Date => s.cast(&DataType::Datetime(TimeUnit::Microseconds, None)),
+            DataType::UInt32 | DataType::UInt64 | DataType::Int32 => s
+                .cast(&DataType::Int64)?
+                .cast(&DataType::Datetime(TimeUnit::Nanoseconds, None)),
+            DataType::Int64 => s.cast(&DataType::Datetime(TimeUnit::Nanoseconds, None)),
+            _ => Ok(s.clone()),
+        })?;
     }
+
+    let mut out = upsample_core(&df, by, index_column, every, stable)?;
+
+    if needs_cast {
+        out.try_apply(index_column, |s| s.cast(original_type))?;
+    }
+
+    Ok(out)
+}
+
+fn upsample_core(
+    source: &DataFrame,
+    by: Vec<PlSmallStr>,
+    index_column: &str,
+    every: Duration,
+    stable: bool,
+) -> PolarsResult<DataFrame> {
+    if by.is_empty() {
+        let index_column = source.column(index_column)?;
+        return upsample_single_impl(source, index_column.as_materialized_series(), every);
+    }
+
+    let source_schema = source.schema();
+
+    let group_keys_df = source.select(by)?;
+    let group_keys_schema = group_keys_df.schema();
+
+    let groups = if stable {
+        group_keys_df.group_by_stable(group_keys_schema.iter_names_cloned())
+    } else {
+        group_keys_df.group_by(group_keys_schema.iter_names_cloned())
+    }?
+    .into_groups();
+
+    let non_group_keys_df = unsafe {
+        source.select_unchecked(
+            source_schema
+                .iter_names()
+                .filter(|name| !group_keys_schema.contains(name.as_str())),
+        )?
+    };
+
+    let upsample_index_col_idx: Option<usize> = non_group_keys_df.schema().index_of(index_column);
+
+    // don't parallelize this, this may SO on large data.
+    let dfs: Vec<DataFrame> = groups
+        .iter()
+        .map(|g| {
+            let first_idx = g.first();
+
+            let mut non_group_keys_df = unsafe { non_group_keys_df.gather_group_unchecked(&g) };
+
+            if let Some(i) = upsample_index_col_idx {
+                non_group_keys_df = upsample_single_impl(
+                    &non_group_keys_df,
+                    non_group_keys_df.columns()[i].as_materialized_series(),
+                    every,
+                )?
+            }
+
+            let mut out = non_group_keys_df;
+
+            let group_keys_df = group_keys_df.new_from_index(first_idx as usize, out.height());
+
+            let out_cols = unsafe { out.columns_mut() };
+
+            out_cols.reserve(group_keys_df.width());
+            out_cols.extend(group_keys_df.into_columns());
+
+            Ok(out)
+        })
+        .collect::<PolarsResult<_>>()?;
+
+    Ok(unsafe {
+        accumulate_dataframes_vertical_unchecked(dfs)
+            .select_unchecked(source_schema.iter_names())?
+            .with_schema(source_schema.clone())
+    })
 }
 
 fn upsample_single_impl(
