@@ -28,7 +28,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
             "r3"=> &[9, 10],
     )?;
     let df_horizontal_concat =
-        polars::functions::concat_df_horizontal(&[df_h1, df_h2], true, false)?;
+        polars::functions::concat_df_horizontal(&[df_h1, df_h2], true, false, false)?;
     println!("{}", &df_horizontal_concat);
     // --8<-- [end:horizontal]
     //
@@ -42,7 +42,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
             "r2"=> &[8, 9, 10],
     )?;
     let df_horizontal_concat =
-        polars::functions::concat_df_horizontal(&[df_h1, df_h2], true, false)?;
+        polars::functions::concat_df_horizontal(&[df_h1, df_h2], true, false, false)?;
     println!("{}", &df_horizontal_concat);
     // --8<-- [end:horizontal_different_lengths]
 
