@@ -847,3 +847,8 @@ def test_fallible_decimal_aggregated_with_filter(maintain_order: bool) -> None:
     out = q.collect()
     expected = pl.DataFrame({"g": [10, 20], "div": [[D("1.0"), D("1.0")], [D("0.5")]]})
     assert_frame_equal(out, expected, check_row_order=maintain_order)
+
+
+def test_decimal_fits_too_large() -> None:
+    with pytest.raises(pl.exceptions.InvalidOperationError):
+        s = pl.Series([0, 2**128 - 10], dtype=pl.UInt128).cast(pl.Decimal(38, 0))
