@@ -285,3 +285,11 @@ def test_err_nested_object() -> None:
 
     with pytest.raises(ComputeError):
         df.select(pl.col("obj").map_elements(mapper, return_dtype=pl.List(pl.Object)))
+
+
+def test_allow_object_after_cache_26182() -> None:
+    _ = pl.Series("b", [object])
+    with pytest.raises(TypeError):
+        (
+            pl.DataFrame({"a": [2]}).rolling(index_column="a", period="2i").agg(str)  # type: ignore[arg-type]
+        )
