@@ -15,6 +15,7 @@ import pytest
 import polars as pl
 from polars.exceptions import ComputeError, SchemaFieldNotFoundError
 from polars.testing import assert_frame_equal, assert_series_equal
+from tests.unit.io.conftest import format_file_uri
 
 if TYPE_CHECKING:
     from collections.abc import Callable
@@ -911,9 +912,16 @@ def test_hive_predicate_dates_14712(
 
 @pytest.mark.skipif(sys.platform != "win32", reason="Test is only for Windows paths")
 @pytest.mark.write_disk
-def test_hive_windows_splits_on_forward_slashes(tmp_path: Path) -> None:
+@pytest.mark.parametrize("prefix", ["", "file:/", "file:///"])
+def test_hive_windows_splits_on_forward_slashes(tmp_path: Path, prefix: str) -> None:
     # Note: This needs to be an absolute path.
     tmp_path = tmp_path.resolve()
+
+    d = str(tmp_path)[:2]
+
+    assert d[0].isalpha()
+    assert d[1] == ":"
+
     path = f"{tmp_path}/a=1/b=1/c=1/d=1/e=1"
     Path(path).mkdir(exist_ok=True, parents=True)
 
@@ -939,17 +947,24 @@ def test_hive_windows_splits_on_forward_slashes(tmp_path: Path) -> None:
     assert_frame_equal(
         pl.scan_parquet(
             [
-                f"{tmp_path}/a=1/b=1/c=1/d=1/e=1/data.parquet",
-                f"{tmp_path}\\a=1\\b=1\\c=1\\d=1\\e=1\\data.parquet",
-                f"{tmp_path}\\a=1/b=1/c=1/d=1/**/*",
-                f"{tmp_path}/a=1/b=1\\c=1/d=1/**/*",
-                f"{tmp_path}/a=1/b=1/c=1/d=1\\e=1/*",
+                f"{prefix}{tmp_path}/a=1/b=1/c=1/d=1/e=1/data.parquet",
+                f"{prefix}{tmp_path}\\a=1\\b=1\\c=1\\d=1\\e=1\\data.parquet",
+                f"{prefix}{tmp_path}\\a=1/b=1/c=1/d=1/**/*",
+                f"{prefix}{tmp_path}/a=1/b=1\\c=1/d=1/**/*",
+                f"{prefix}{tmp_path}/a=1/b=1/c=1/d=1\\e=1/*",
             ],
             hive_partitioning=True,
         ).collect(),
         expect,
     )
 
+    q = pl.scan_parquet("file://C:/")
+
+    with pytest.raises(
+        ComputeError, match="unsupported: non-empty hostname for 'file:' URI: 'C:'"
+    ):
+        q.collect()
+
 
 @pytest.mark.write_disk
 def test_passing_hive_schema_with_hive_partitioning_disabled_raises(
@@ -1000,7 +1015,7 @@ def test_hive_file_as_uri_with_hive_start_idx_23830(
     # ensure we have a trailing "/"
     uri = tmp_path.resolve().as_posix().rstrip("/") + "/"
 
-    lf = pl.scan_parquet(f"file://{uri}", hive_schema={"a": pl.UInt8})
+    lf = pl.scan_parquet(format_file_uri(uri), hive_schema={"a": pl.UInt8})
 
     assert_frame_equal(
         lf.collect(),
@@ -1010,18 +1025,17 @@ def test_hive_file_as_uri_with_hive_start_idx_23830(
         ),
     )
 
-    if sys.platform != "win32":
-        # https://github.com/pola-rs/polars/issues/24506
-        # `file:` URI with `//hostname` component omitted
-        lf = pl.scan_parquet(f"file:{uri}", hive_schema={"a": pl.UInt8})
+    # https://github.com/pola-rs/polars/issues/24506
+    # `file:` URI with `//hostname` component omitted
+    lf = pl.scan_parquet(f"file:{uri}", hive_schema={"a": pl.UInt8})
 
-        assert_frame_equal(
-            lf.collect(),
-            pl.select(
-                pl.Series("x", [1]),
-                pl.Series("a", [1], dtype=pl.UInt8),
-            ),
-        )
+    assert_frame_equal(
+        lf.collect(),
+        pl.select(
+            pl.Series("x", [1]),
+            pl.Series("a", [1], dtype=pl.UInt8),
+        ),
+    )
 
 
 @pytest.mark.write_disk
