@@ -1389,7 +1389,7 @@ def test_sink_parquet_arrow_schema_logical_types() -> None:
         }
     )
 
-    with pytest.raises(SchemaError, match=r"Dictionary\(UInt32, Utf8View, false\)"):
+    with pytest.raises(SchemaError, match=r"Dictionary\(UInt32, LargeUtf8, false\)"):
         df.select("categorical").lazy().sink_parquet(
             io.BytesIO(),
             arrow_schema=pa.schema(
@@ -1400,7 +1400,7 @@ def test_sink_parquet_arrow_schema_logical_types() -> None:
     df.select("categorical").lazy().sink_parquet(
         io.BytesIO(),
         arrow_schema=pa.schema(
-            [pa.field("categorical", pa.dictionary(pa.uint32(), pa.string_view()))],
+            [pa.field("categorical", pa.dictionary(pa.uint32(), pa.large_string()))],
         ),
     )
 
@@ -1433,11 +1433,11 @@ def test_sink_parquet_arrow_schema_logical_types() -> None:
             ) -> Any:
                 return PythonTestExtensionPyarrow(storage_type[0].type)
 
-        return PythonTestExtensionPyarrow(pa.string_view())
+        return PythonTestExtensionPyarrow(pa.large_string())
 
     with pytest.raises(
         SchemaError,
-        match=r'Extension\(ExtensionType { name: "testing.python_test_extension", inner: Utf8View, metadata: None }\)',
+        match=r'Extension\(ExtensionType { name: "testing.python_test_extension", inner: LargeUtf8, metadata: None }\)',
     ):
         df.select("extension[str]").lazy().sink_parquet(
             io.BytesIO(),
@@ -1553,3 +1553,64 @@ def test_sink_parquet_arrow_schema_nested_types() -> None:
             ],
         ),
     )
+
+
+def test_sink_parquet_writes_strings_as_largeutf8_by_default() -> None:
+    df = pl.DataFrame({"string": "A", "binary": [b"A"]})
+
+    with pytest.raises(
+        SchemaError,
+        match=r"provided dtype \(Utf8View\) does not match output dtype \(LargeUtf8\)",
+    ):
+        df.lazy().select("string").sink_parquet(
+            io.BytesIO(), arrow_schema=pa.schema([pa.field("string", pa.string_view())])
+        )
+
+    with pytest.raises(
+        SchemaError,
+        match=r"provided dtype \(BinaryView\) does not match output dtype \(LargeBinary\)",
+    ):
+        df.lazy().select("binary").sink_parquet(
+            io.BytesIO(), arrow_schema=pa.schema([pa.field("binary", pa.binary_view())])
+        )
+
+    f = io.BytesIO()
+
+    arrow_schema = pa.schema(
+        [
+            pa.field("string", pa.large_string()),
+            pa.field("binary", pa.large_binary()),
+        ]
+    )
+
+    df.lazy().sink_parquet(f, arrow_schema=arrow_schema)
+
+    f.seek(0)
+
+    assert pq.read_schema(f) == arrow_schema
+
+    f.seek(0)
+
+    assert_frame_equal(pl.scan_parquet(f).collect(), df)
+
+
+def test_sink_parquet_pyarrow_filter_string_type_26435() -> None:
+    df = pl.DataFrame({"string": ["A", None, "B"], "int": [0, 1, 2]})
+
+    f = io.BytesIO()
+
+    df.write_parquet(f)
+
+    f.seek(0)
+
+    assert_frame_equal(
+        pl.DataFrame(pq.read_table(f, filters=[("int", "=", 0)])),
+        pl.DataFrame({"string": "A", "int": 0}),
+    )
+
+    f.seek(0)
+
+    assert_frame_equal(
+        pl.DataFrame(pq.read_table(f, filters=[("string", "=", "A")])),
+        pl.DataFrame({"string": "A", "int": 0}),
+    )
