@@ -7,6 +7,7 @@ import pytest
 
 import polars as pl
 from polars.testing.asserts.frame import assert_frame_equal
+from tests.unit.io.conftest import format_file_uri
 
 if TYPE_CHECKING:
     from collections.abc import Callable
@@ -44,7 +45,7 @@ def test_write_async(
 ) -> None:
     tmp_path.mkdir(exist_ok=True)
     path = (tmp_path / "1").absolute()
-    path = f"file://{path}"  # type: ignore[assignment]
+    path = format_file_uri(path)  # type: ignore[assignment]
 
     df = pl.DataFrame({"x": 1})
 
