@@ -1,3 +1,4 @@
+import warnings
 from typing import Any
 
 import pytest
@@ -7,7 +8,10 @@ import polars as pl
 
 @pytest.mark.slow
 def test_show_versions(capsys: Any) -> None:
-    pl.show_versions()
+    with warnings.catch_warnings():
+        # Ignore DeprecationWarnings from dependency imports.
+        warnings.simplefilter("ignore", DeprecationWarning)
+        pl.show_versions()
 
     out, _ = capsys.readouterr()
     assert "Python" in out
