@@ -865,7 +865,7 @@ def test_offset_by() -> None:
     assert df["date_min"].to_list() == expected_dates
 
 
-@pytest.mark.parametrize("time_zone", ["US/Central", None])
+@pytest.mark.parametrize("time_zone", ["America/Chicago", None])
 def test_offset_by_crossing_dst(time_zone: str | None) -> None:
     ser = pl.Series([datetime(2021, 11, 7)]).dt.replace_time_zone(time_zone)
     result = ser.dt.offset_by("1d")
@@ -1440,20 +1440,19 @@ def test_dt_mean_deprecated() -> None:
     [
         pl.Date,
         pl.Datetime("ms"),
-        pl.Datetime("ms", "EST"),
+        pl.Datetime("ms", "America/New_York"),
         pl.Datetime("us"),
-        pl.Datetime("us", "EST"),
+        pl.Datetime("us", "America/New_York"),
         pl.Datetime("ns"),
-        pl.Datetime("ns", "EST"),
+        pl.Datetime("ns", "America/New_York"),
     ],
 )
 @pytest.mark.parametrize(
     "value",
     [
-        # date(1677, 9, 22), # See test_literal_from_datetime.
+        date(1677, 9, 22),
         date(1970, 1, 1),
         date(2024, 2, 29),
-        date(2262, 4, 11),
     ],
 )
 def test_literal_from_date(
@@ -1473,29 +1472,22 @@ def test_literal_from_date(
     [
         pl.Date,
         pl.Datetime("ms"),
-        pl.Datetime("ms", "EST"),
+        pl.Datetime("ms", "America/New_York"),
         pl.Datetime("us"),
-        pl.Datetime("us", "EST"),
+        pl.Datetime("us", "America/New_York"),
         pl.Datetime("ns"),
-        pl.Datetime("ns", "EST"),
+        pl.Datetime("ns", "America/New_York"),
     ],
 )
 @pytest.mark.parametrize(
     "value",
     [
-        # Very old dates with a timezone like EST caused problems for the CI due
-        # to the IANA timezone database updating their historical offset, so
-        # these have been disabled for now. A mismatch between the timezone
-        # database that chrono_tz crate uses vs. the one that Python uses (which
-        # differs from platform to platform) will cause this to fail.
-        # datetime(1677, 9, 22),
-        # datetime(1677, 9, 22, tzinfo=ZoneInfo("EST")),
+        datetime(1677, 9, 22),
+        datetime(1677, 9, 22, tzinfo=ZoneInfo("America/New_York")),
         datetime(1970, 1, 1),
-        datetime(1970, 1, 1, tzinfo=ZoneInfo("EST")),
+        datetime(1970, 1, 1, tzinfo=ZoneInfo("America/New_York")),
         datetime(2024, 2, 29),
-        datetime(2024, 2, 29, tzinfo=ZoneInfo("EST")),
-        datetime(2262, 4, 11),
-        datetime(2262, 4, 11, tzinfo=ZoneInfo("EST")),
+        datetime(2024, 2, 29, tzinfo=ZoneInfo("America/New_York")),
     ],
 )
 def test_literal_from_datetime(
