@@ -484,10 +484,10 @@ def test_strptime_invalid_timezone() -> None:
 def test_to_datetime_ambiguous_or_non_existent() -> None:
     with pytest.raises(
         ComputeError,
-        match="datetime '2021-11-07 01:00:00' is ambiguous in time zone 'US/Central'",
+        match="datetime '2021-11-07 01:00:00' is ambiguous in time zone 'America/Chicago'",
     ):
         pl.Series(["2021-11-07 01:00"]).str.to_datetime(
-            time_unit="us", time_zone="US/Central"
+            time_unit="us", time_zone="America/Chicago"
         )
     with pytest.raises(
         ComputeError,
