@@ -1,7 +1,10 @@
 from datetime import datetime
 
+from hypothesis import given
+
 import polars as pl
 from polars.testing import assert_series_equal
+from polars.testing.parametric import series
 
 
 def test_unique_counts() -> None:
@@ -41,3 +44,16 @@ def test_unique_counts_null() -> None:
     s = pl.Series([None, None, None])
     expected = pl.Series([3], dtype=pl.get_index_type())
     assert_series_equal(s.unique_counts(), expected)
+
+
+@given(s=series(excluded_dtypes=[pl.Object]))
+def test_unique_counts_parametric(s: pl.Series) -> None:
+    result = s.unique_counts()
+    expected = (
+        s.to_frame()
+        .group_by(s.name, maintain_order=True)
+        .agg(pl.len())
+        .get_columns()[1]
+    )
+
+    assert_series_equal(result, expected, check_names=False)
